# ThaBox

![ThaBox](https://github.com/MikeNoCap/ThaBox/blob/ThaBox/images/ThaBox_50.png?raw=true)

ThaBox is an open-source, terminal-based, retro-modern chat application where clients can connect to chatrooms and talk anonymously.
You just create an account and `BOOM`, you now have access to all of ThaBox.



## Authors

Team Jazzed Jerboas - tomheaton, MikeNoCap, HiPeople21, TahU28, ryoflux, b-a-b-i-s